==> ejc-jlincome-impl-3.0.0-20240713.013625-169-sources.jar: com/ejianc/business/jlincome/income/bean/DisclosureConDetailsEntity.java <==
package com.ejianc.business.jlincome.income.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 收入管理-合同交底-合同明细子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_income_disclosure_contract_details")
public class DisclosureConDetailsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="disclosure_id")
    private Long disclosureId; // 主表id
    @TableField(value="detail_product_name")
    private String detailProductName; // 产品名称
    @TableField(value="detail_spec")
    private String detailSpec; // 规格型号
    @TableField(value="detail_unit")
    private String detailUnit; // 单位
    @TableField(value="detail_num")
    private BigDecimal detailNum; // 数量
    @TableField(value="detail_tax_price")
    private BigDecimal detailTaxPrice; // 单价
    @TableField(value="detail_rate")
    private BigDecimal detailRate; // 税率
    @TableField(value="detail_tax_mny")
    private BigDecimal detailTaxMny; // 金额
    @TableField(value="detail_price")
    private BigDecimal detailPrice; // 单价（无税）
    @TableField(value="detail_mny")
    private BigDecimal detailMny; // 金额（无税）
    @TableField(value="detail_tax")
    private BigDecimal detailTax; // 税额
    @TableField(value="detail_plan_deliver_date")
    private Date detailPlanDeliverDate; // 预计交货日期
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    public Date getDetailPlanDeliverDate() {
        return detailPlanDeliverDate;
    }

    public void setDetailPlanDeliverDate(Date detailPlanDeliverDate) {
        this.detailPlanDeliverDate = detailPlanDeliverDate;
    }
    
    
    

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }
    public String getDetailProductName() {
        return detailProductName;
    }

    public void setDetailProductName(String detailProductName) {
        this.detailProductName = detailProductName;
    }
    public String getDetailSpec() {
        return detailSpec;
    }

    public void setDetailSpec(String detailSpec) {
        this.detailSpec = detailSpec;
    }
    public String getDetailUnit() {
        return detailUnit;
    }

    public void setDetailUnit(String detailUnit) {
        this.detailUnit = detailUnit;
    }
    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }
    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }
    public BigDecimal getDetailRate() {
        return detailRate;
    }

    public void setDetailRate(BigDecimal detailRate) {
        this.detailRate = detailRate;
    }
    public BigDecimal getDetailTaxMny() {
        return detailTaxMny;
    }

    public void setDetailTaxMny(BigDecimal detailTaxMny) {
        this.detailTaxMny = detailTaxMny;
    }
    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public BigDecimal getDetailTax() {
        return detailTax;
    }

    public void setDetailTax(BigDecimal detailTax) {
        this.detailTax = detailTax;
    }

    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}

==> ejc-jlincome-impl-3.0.0-20240930.032106-242-sources.jar: com/ejianc/business/jlincome/income/bean/DisclosureConDetailsEntity.java <==
package com.ejianc.business.jlincome.income.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 收入管理-合同交底-合同明细子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_income_disclosure_contract_details")
public class DisclosureConDetailsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="disclosure_id")
    private Long disclosureId; // 主表id
    @TableField(value="detail_product_name")
    private String detailProductName; // 产品名称
    @TableField(value="detail_spec")
    private String detailSpec; // 规格型号
    @TableField(value="detail_unit")
    private String detailUnit; // 单位
    @TableField(value="detail_num")
    private BigDecimal detailNum; // 数量
    @TableField(value="detail_tax_price")
    private BigDecimal detailTaxPrice; // 单价
    @TableField(value="detail_rate")
    private BigDecimal detailRate; // 税率
    @TableField(value="detail_tax_mny")
    private BigDecimal detailTaxMny; // 金额
    @TableField(value="detail_price")
    private BigDecimal detailPrice; // 单价（无税）
    @TableField(value="detail_mny")
    private BigDecimal detailMny; // 金额（无税）
    @TableField(value="detail_tax")
    private BigDecimal detailTax; // 税额
    @TableField(value="detail_plan_deliver_date")
    private Date detailPlanDeliverDate; // 预计交货日期
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value = "bill_code")
    private String billCode; //计划单号
    @TableField(value = "source_id")
    private Long sourceId;//计划子表Id

    @TableField(value = "source_bill_id")
    private Long sourceBillId;//计划主表id

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getSourceBillId() {
        return sourceBillId;
    }

    public void setSourceBillId(Long sourceBillId) {
        this.sourceBillId = sourceBillId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Date getDetailPlanDeliverDate() {
        return detailPlanDeliverDate;
    }

    public void setDetailPlanDeliverDate(Date detailPlanDeliverDate) {
        this.detailPlanDeliverDate = detailPlanDeliverDate;
    }
    
    
    

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }
    public String getDetailProductName() {
        return detailProductName;
    }

    public void setDetailProductName(String detailProductName) {
        this.detailProductName = detailProductName;
    }
    public String getDetailSpec() {
        return detailSpec;
    }

    public void setDetailSpec(String detailSpec) {
        this.detailSpec = detailSpec;
    }
    public String getDetailUnit() {
        return detailUnit;
    }

    public void setDetailUnit(String detailUnit) {
        this.detailUnit = detailUnit;
    }
    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }
    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }
    public BigDecimal getDetailRate() {
        return detailRate;
    }

    public void setDetailRate(BigDecimal detailRate) {
        this.detailRate = detailRate;
    }
    public BigDecimal getDetailTaxMny() {
        return detailTaxMny;
    }

    public void setDetailTaxMny(BigDecimal detailTaxMny) {
        this.detailTaxMny = detailTaxMny;
    }
    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public BigDecimal getDetailTax() {
        return detailTax;
    }

    public void setDetailTax(BigDecimal detailTax) {
        this.detailTax = detailTax;
    }

    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}
